Dygraphs JS Library Packaged for Plone
======================================

This package provides the
`Dygraphs JS Charting Libray <http://dygraphs.com/>`_ for use in Plone.

**dygraphs is a fast, flexible open source JavaScript charting library** (cite
from the original website)


Installation
============

Just depend in your buildout on the egg ``collective.js.dygraphs``.

Install ``Dygraphs Javascript Library`` as an addon in Plone control-panel or
in portal_setup.

GenericSetup dependency string for metadata.xml is
``profile-collective.js.dygraphs-default``.

At the moment theres no uninstall profile configured.

This package is tested with for Plone 4.3 (should work with the 4-series).


Source Code and Contributions
=============================

If you want to help with the development (improvement, update, bug-fixing, ...)
of ``collective.js.dygraphs`` this is a great idea!

The code is located in the
`github collective <https://github.com/collective/collective.js.dygraphs>`_.

You can clone it or `get access to the github-collective
<http://collective.github.com/>`_ and work directly on the project.

Maintainer is Jens Klein and the BlueDynamics Alliance developer team. We
appreciate any contribution and if a release is needed to be done on pypi,
please just contact one of us
`dev@bluedynamics dot com <mailto:dev@bluedynamics.com>`_


Contributors
============

- Jens W. Klein <jens@bluedynamics.com>

License Python Package is **GPL 2**

License external libray Dygraphs is **MIT License** see
`Dygraphs Legal Page <http://dygraphs.com/legal.html>`_

